OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Lõimitud e-kiri %s",
    "Important mail" : "Oluline e-kiri",
    "No message found yet" : "Ei leidu veel ühtegi kirja",
    "Set up an account" : "Seadista kasutajakonto",
    "Unread mail" : "Lugemata kirjad",
    "Important" : "Tähtis",
    "Work" : "Töö",
    "Personal" : "Isiklik",
    "To Do" : "Tegemiseks",
    "Later" : "Hiljem",
    "Mail" : "Kirjad",
    "You are reaching your mailbox quota limit for {account_email}" : "„{account_email}“ konto mahukvoot on varsti täis",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "Kasutad praegu {percentage} oma postkasti andmeruumist. Palun kustuta mittevajalikud kirjad ning saada andmeruumi juurde.",
    "Mail Application" : "E-posti rakendus",
    "Mails" : "E-kirjad",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following email: %3$s" : "Saatja aadress %1$s pole aadressiraamatus, aga %2$s nimi on ning temaga on seotud järgnev aadress: %3$s",
    "Sender email: %1$s is not in the address book, but the sender name: %2$s is in the address book with the following emails: %3$s" : "Saatja aadress %1$s pole aadressiraamatus, aga %2$s nimi on ning temaga on seotud järgnevad aadressid: %3$s",
    "Sender is using a custom email: %1$s instead of the sender email: %2$s" : "Saatja kasutab muudetud e-postiaadressi %1$s oma tavalise %2$s aadressi asemel",
    "Sent date is in the future" : "Saatmise kuupäev on tulevikus",
    "Mail server marked this message as phishing attempt" : "E-posti server märkis selle e-kirja õngitsuskatseks",
    "Some addresses in this message are not matching the link text" : "Mõned selle kirja aadressid ei vasta lingi tekstile",
    "Reply-To email: %1$s is different from sender email: %2$s" : "Vastamiseks mõeldud e-posti aadress: %1$s on erinev saatja aadressist %2$s",
    "Mail connection performance" : "E-postiteenuse ühenduse jõudlus",
    "Mail account parameters, aliases and preferences" : "E-posti kasutajakonto parameetrid, aliased ja eelistused",
    "💌 A mail app for Nextcloud" : "💌 E-postirakendus Nextcloudi jaoks",
    "Your session has expired. The page will be reloaded." : "Sinu sessioon on aegunud. Leht saab olema uuesti laaditud.",
    "Drafts are saved in:" : "Kirjade kavandis on salvestatud siia:",
    "Sent messages are saved in:" : "Saadetud kirjad on salvestatud siia:",
    "Deleted messages are moved in:" : "Kustutatud kirjad on tõstetud siia:",
    "Archived messages are moved in:" : "Arhiveeritud kirjad on tõstetud siia:",
    "Snoozed messages are moved in:" : "Edasilükatud kirjad on tõstetud siia:",
    "Junk messages are saved in:" : "Rämpskirjad on salvestatud siia:",
    "Connecting" : "Ühendamisel",
    "Reconnect Google account" : "Ühenda Google'i kontoga uuesti",
    "Sign in with Google" : "Logi sisse Google'i kontoga",
    "Reconnect Microsoft account" : "Ühenda Microsofti kontoga uuesti",
    "Sign in with Microsoft" : "Logi sisse Microsofti kontoga",
    "Save" : "Salvesta",
    "Connect" : "Ühenda",
    "Looking up configuration" : "Tuvastan seadistusi",
    "Checking mail host connectivity" : "Tuvastan postiserveri ühendusi",
    "Configuration discovery failed. Please use the manual settings" : "Seadistuste automaatne tuvastamine ei õnnestunud. Palun seadista käsitsi.",
    "Password required" : "Salasõna on vajalik",
    "Testing authentication" : "Testin autentimist",
    "Awaiting user consent" : "Ootan kasutaja nõusolekut",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Kasutajakonto on loodud. Sidumaks seda oma Google'i kontoga palun järgi hüpikaknas kuvatud juhendit",
    "Account created. Please follow the pop-up instructions to link your Microsoft account" : "Kasutajakonto on loodud. Sidumaks seda oma Microsofti kontoga palun järgi hüpikaknas kuvatud juhendit",
    "Loading account" : "Laadin kasutajakontot",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Kasutajakonto on uuendatud. Sidumaks seda uuesti oma Google'i kontoga palun järgi hüpikaknas kuvatud juhendit",
    "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "Kasutajakonto on uuendatud. Sidumaks seda uuesti oma Microsofti kontoga palun järgi hüpikaknas kuvatud juhendit",
    "Account updated" : "Konto on uuendatud",
    "IMAP server is not reachable" : "IMAP-i server pole leitav",
    "SMTP server is not reachable" : "SMTP server pole leitav",
    "IMAP username or password is wrong" : "IMAP-i kasutajanimi või salasõna on valed",
    "SMTP username or password is wrong" : "SMTP kasutajanimi või salasõna on valed",
    "IMAP server denied authentication" : "IMAP-i server keeldus autentimisest",
    "SMTP server denied authentication" : "SMTP server keeldus autentimisest",
    "IMAP authentication error" : "IMAP-i autentimisviga",
    "SMTP authentication error" : "SMTP autentimisviga",
    "IMAP connection failed" : "IMAP-i ühendust ei õnnestunud luua",
    "SMTP connection failed" : "SMTP ühendust ei õnnestunud luua",
    "Authorization pop-up closed" : "Autentimise hüpikaken on suletud",
    "Configuration discovery temporarily not available. Please try again later." : "Seadistuste automaatne tuvastamine pole ajutiselt saadaval. Palun proovi hiljem uuesti.",
    "There was an error while setting up your account" : "Sinu kasutajakonto kasutuselevõtmisel tekkis viga",
    "Auto" : "Automaatne",
    "Name" : "Nimi",
    "Mail address" : "E-posti aadress",
    "name@example.org" : "nimi@toredomeen.ee",
    "Please enter an email of the format name@example.com" : "Palun sisesta e-posti aadress nimi@toredomeen.ee vormingus",
    "Password" : "Salasõna",
    "Enable mark as important classification" : "Kasuta märget olulise klassifikaatorina",
    "Manual" : "Käsitsi",
    "IMAP Settings" : "IMAP-i seadistused",
    "IMAP Host" : "IMAP-i server",
    "IMAP Security" : "IMAP-i turvalisus",
    "None" : "Pole kasutusel",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-i port",
    "IMAP User" : "IMAP-i kasutajanimi",
    "IMAP Password" : "IMAP-i salasõna",
    "SMTP Settings" : "SMTP seadistused",
    "SMTP Host" : "SMTP server",
    "SMTP Security" : "SMTP turvalisus",
    "SMTP Port" : "SMTP port",
    "SMTP User" : "SMTP kasutajanimi",
    "SMTP Password" : "SMTP salasõna",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "Kui soovid, et Google'i konto toimiks siin rakenduses, siis pead seal kasutusele võtma kaheastmelise autentimise ja looma rakendusele salasõna.",
    "Account settings" : "Konto seadistused",
    "Aliases" : "Aliased",
    "Alias to S/MIME certificate mapping" : "Alias S/MIME sertifikaatide vastavuse jaoks",
    "Signature" : "Allkiri",
    "A signature is added to the text of new messages and replies." : "Allkiri lisatakse uutele kirjadele ja vastustele.",
    "Writing mode" : "Kirjutusviis",
    "Preferred writing mode for new messages and replies." : "Kirjutusviis uute kirjade ning vastuste jaoks.",
    "Default folders" : "Vaikimisi kaustad",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "Kaustad kavandite, saadetud ja kustutatud kirjade ning arhiveeri ning rämpskirjade jaoks.",
    "Automatic trash deletion" : "Prügikasti automaatne tühjenadmine",
    "Days after which messages in Trash will automatically be deleted:" : "Päevade arv, mille möödumisel peaks prügikasti visatudkirjad automaatselt kustutatama",
    "Autoresponder" : "Automaatvastaja",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automaatsed vastused saabunud kirjadele. Kui keegi saadab sulle enam  kui ühe kirja, siis saab ta automaatse vastuse kord 4 päeva jooksul.",
    "The autoresponder uses Sieve, a scripting language supported by many email providers. If you're unsure whether yours does, check with your provider. If Sieve is available, click the button to go to the settings and enable it." : "Automaatvastaja on loodud Sieve skriptimiskeeles ja tavaliselt on selline võimalus toetatud paljude e-posti teenuste puhul. Kui sa pole enda omas kindel, siis palun küsi neilt üle. Kui Sieve on kasutatav, siis klõpsi järgnevat nuppu ja võta ta seadistustest kasutusele.",
    "Go to Sieve settings" : "Ava Sieve seadistused",
    "Calendar settings" : "Kalendri seadistused",
    "Classification settings" : "Klassifitseerimise seadistused",
    "Filters" : "Filtrid",
    "Quick actions" : "Kiirtoimingud",
    "Sieve script editor" : "Sieve skriptikoostaja",
    "Mail server" : "E-posti server",
    "Sieve server" : "Sieve server",
    "Folder search" : "Kaustade otsing",
    "Update alias" : "Uuenda aliast",
    "Rename alias" : "Muuda aliast",
    "Show update alias form" : "Näita uuendatud aliast",
    "Delete alias" : "Kustuta alias",
    "Go back" : "Mine tagasi",
    "Change name" : "Muuda nime",
    "Email address" : "E-posti aadress",
    "Add alias" : "Lisa alias",
    "Create alias" : "Loo alias",
    "Cancel" : "Katkesta",
    "Search the body of messages in priority Inbox" : "Otsi esmase postkasti kirjade sisust",
    "Activate" : "Lülita sisse",
    "Remind about messages that require a reply but received none" : "Tuleta mulle meelde kirju, mis eeldavad vastust, kui pole seda veel saanud",
    "Highlight external addresses" : "Tõsta välised aadressid esile",
    "Could not update preference" : "Eelistust polnud võimalik muuta",
    "Mail settings" : "E-kirjade seadistused",
    "General" : "Üldine",
    "Set as default mail app" : "Määra vaikimisi e-postirakenduseks",
    "Add mail account" : "Lisa e-posti  konto",
    "Appearance" : "Välimus",
    "Show all messages in thread" : "Näita kõiki kirju jutulõngas",
    "When off, only the selected message will be shown" : "Kui eelistus pole kasutusel, siis näidatakse vaid valitud kirja",
    "Sort favorites up" : "Järjesta lemmikud esimesena",
    "When on, favorite messages will be sorted to the top of folders" : "Kui see valik on kasutusel, siis lemmikud järjestuvad kaustas esimestena",
    "Layout" : "Välimus",
    "Vertical split" : "Püstjoones jagamine",
    "Horizontal split" : "Rõhtjoones jagamine",
    "List" : "Nimekiri",
    "Use compact mode" : "Kasuta kompaktset vaadet",
    "Sorting" : "Järjestus",
    "Newest first" : "Uuemad eespool",
    "Oldest first" : "Vanemad eespool",
    "Avatars from Gravatar and favicons" : "Favikonid ja tunnuspildid teenusest Gravatar",
    "Reply position" : "Vastuse asukoht",
    "Top" : "Üleval",
    "Bottom" : "All",
    "Text blocks" : "Tekstiplokid",
    "Reusable pieces of text that can be inserted in messages" : "Teksti kasutatavad osad, misa saad kirjadesse lisada",
    "New text block" : "Uus tekstiplokk",
    "Shared with me" : "Jagatud minuga",
    "Privacy" : "Privaatsus",
    "Data collection" : "Andmete kogumine",
    "Allow the app to collect and process data locally to adapt to your preferences" : "Luba rakendusel kohalikus seadmes andmeid koguda ja töödelda ning lasta kohanduda sinu eelistustega",
    "Always show images from" : "Alati näita pilte saatjalt",
    "Security" : "Turvalisus",
    "Manage your internal addresses and domains to ensure recognized contacts stay unmarked" : "Halda sinu serveri sisemisi aadresse ja domeene. Nii tagatakse, et sinu poolt kinnitatud kontaktid jäävad esiletõstmata",
    "S/MIME" : "S/MIME",
    "Manage certificates" : "Halda sertifikaate",
    "Mailvelope" : "Mailvelope",
    "Mailvelope is enabled for the current domain." : "Mailvelope on selle domeeni puhul kasutusel.",
    "Step 1" : "1. samm",
    "Install the browser extension" : "Paigalda veebibrauseri laiendus/lisamoodul",
    "Step 2" : "2. samm",
    "Enable for the current domain" : "Luba  kasutamine selle domeeni puhul",
    "Assistance features" : "Abilise funktsionaalsused",
    "Compose new message" : "Koosta uus kiri",
    "Newer message" : "Uuem kiri",
    "Older message" : "Vane kiri",
    "Toggle star" : "Lülita lemmikuks märkimine sisse/välja",
    "Toggle unread" : "Lülita loetuks märkimine sisse/välja",
    "Archive" : "Arhiiv",
    "Delete" : "Kustuta",
    "Search" : "Otsi",
    "Send" : "Saada",
    "Refresh" : "Värskenda",
    "About" : "Rakenduse teave",
    "Acknowledgements" : "Tänuavaldused",
    "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Selles rakenduses sisaldub avatud lähtekoodiga CKEditor, mis on kasutusel kirjade koostamiseks. Autoriõigused: © CKEditori kaasautorid. Litsentseeritud GPLv2 alusel.",
    "Title of the text block" : "Tekstiploki pealkiri",
    "Content of the text block" : "Tekstiploki sisu",
    "Ok" : "Sobib",
    "No certificate" : "Sertifikaati pole",
    "Certificate updated" : "Sertifikaat on uuendatud",
    "Could not update certificate" : "Sertifikaadi uuendamine ei õnnestunud",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Kehtiv kuni {expiryDate}",
    "Select an alias" : "Vali alias",
    "Select certificates" : "Vali sertifikaadid",
    "Update Certificate" : "Uuenda sertifikaati",
    "The selected certificate is not trusted by the server. Recipients might not be able to verify your signature." : "Valitud sertifikaat pole serveri jaoks usaldusväärne. Kirjade saajad ei pruugi suuta sinu allkirja verifitseerida.",
    "Encrypt with S/MIME and send later" : "Krüpti kiri S/MIME-ga ja saada hiljem",
    "Encrypt with S/MIME and send" : "Krüpti kiri S/MIME-ga ja saada kohe",
    "Encrypt with Mailvelope and send later" : "Krüpti kiri Mailvelope'iga ja saada hiljem",
    "Encrypt with Mailvelope and send" : "Krüpti kiri Mailvelope'iga ja saada kohe",
    "Send later" : "Saada hiljem",
    "Message {id} could not be found" : "Kirja tunnusega „{id}“ ei õnnestu leida",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Oled valinud, et soovid S/MIME abil allkirjastada või krüptida, kuid valitud aliase jaoks pole meil sertifikaati. Järgnev kiri jääb allkirjastamata või krüptimata.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Kõik olemasolev vormindus (näiteks paks kiri, värviline tekst ja tekstis olevad pildid) saab järgnevaga eemaldatud.",
    "Turn off formatting" : "Lülita vormindus välja",
    "Turn off and remove formatting" : "Lülita välja ja eemalda vorming",
    "Keep formatting" : "Säilita vorming",
    "From" : "Saatja",
    "Select account" : "Vali kasutajakonto",
    "To" : "Saaja",
    "Cc/Bcc" : "Cc/Bcc",
    "Select recipient" : "Vali kirja saaja",
    "Contact or email address …" : "Kontakt või e-posti aadress…",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "Teema",
    "Subject …" : "Teema…",
    "This message came from a noreply address so your reply will probably not be read." : "See kiri on saadetud aadressilt, kuhu vastuseid ei oodata ja seega sinu saadetud vastust ilmselt mitte keegi ei loe.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "Järgnevatel saajatel puudub S/MIME sertifikaat: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "Järgnevatel saajatel puudub PGP võti: {recipients}.",
    "Write message …" : "Koosta kiri…",
    "Saving draft …" : "Salvestan kavandit…",
    "Error saving draft" : "Viga kavandi salvestamisel",
    "Draft saved" : "Kavand on salvestatud",
    "Save draft" : "Salvesta kavand",
    "Discard & close draft" : "Loobu muudatustest ja sulge kavand",
    "Enable formatting" : "Kasuta vormindust",
    "Disable formatting" : "Ära kasuta vormindust",
    "Upload attachment" : "Laadi manus üles",
    "Add attachment from Files" : "Lisa manus failirakendusest",
    "Add share link from Files" : "Lisa jagamislink failirakendusest",
    "Smart picker" : "Nutivalija",
    "Request a read receipt" : "Palu lugemiskinnitust",
    "Sign message with S/MIME" : "Allkirjasta kiri S/MIME-ga",
    "Encrypt message with S/MIME" : "Krüpti kiri S/MIME-ga",
    "Encrypt message with Mailvelope" : "Krüpti kiri Mailvelope'iga",
    "Send now" : "Saada kohe",
    "Tomorrow morning" : "Homme hommikul",
    "Tomorrow afternoon" : "Homme pärastlõunal",
    "Monday morning" : "Esmaspäeva hommikul",
    "Custom date and time" : "Valutud kuupäeval ja kellaajal",
    "Enter a date" : "Sisesta kuupäev",
    "Choose" : "Vali",
    "_The attachment exceed the allowed attachments size of {size}. Please share the file via link instead._::_The attachments exceed the allowed attachments size of {size}. Please share the files via link instead._" : ["Manuse maht ületab lubatud suuruse {size}. Selle asemel palun jaga seda faili lingiga.","Manuste maht ületab lubatud suuruse {size}. Selle asemel palun jaga neid faile lingiga."],
    "Choose a file to add as attachment" : "Vali fail, mida manustada",
    "Choose a file to share as a link" : "Vali lingiga jagatav fail",
    "_{count} attachment_::_{count} attachments_" : ["{count} manus","{count} manust"],
    "Untitled message" : "Ilma pealkirjata kiri",
    "Expand composer" : "Näita koostamisvaadet laiemana",
    "Close composer" : "Sulge koostamisvaade",
    "Confirm" : "Kinnita",
    "Tag: {name} deleted" : "Silt: {name} on kustutatud",
    "An error occurred, unable to delete the tag." : "Tekkis viga, silti ei õnnestu kustutada",
    "The tag will be deleted from all messages." : "See silt saab olema eemaldatud kõikide kirjade juurest.",
    "Plain text" : "Vormindamata tekst",
    "Rich text" : "Vormindatud tekst",
    "No messages in this folder" : "Selles kaustas pole kirju",
    "No messages" : "Kirju pole",
    "Blind copy recipients only" : "Vaid pimekoopia saajad",
    "No subject" : "Teemat pole",
    "{markup-start}Draft:{markup-end} {subject}" : "{markup-start}Kavand:{markup-end} {subject}",
    "Later today – {timeLocale}" : "Täna hiljem – {timeLocale}",
    "Set reminder for later today" : "Lisa meeldetuletus tänaseks hilisemaks ajaks",
    "Tomorrow – {timeLocale}" : "Homme – {timeLocale}",
    "Set reminder for tomorrow" : "Lisa meeldetuletus homseks",
    "This weekend – {timeLocale}" : "Sel nädalavahetusel – {timeLocale}",
    "Set reminder for this weekend" : "Lisa meeldetuletus selleks nädalavahetuseks",
    "Next week – {timeLocale}" : "Järgmisel nädalal – {timeLocale}",
    "Set reminder for next week" : "Lisa meeldetuletus järgmiseks nädalaks",
    "Could not apply tag, configured tag not found" : "Sildi lisamine ei õnnestunud, seadistatud silti ei leidu",
    "Could not move thread, destination mailbox not found" : "Jutulõnga teisaldamine ei õnnestunud, sihtpostkasti ei leidu",
    "Could not execute quick action" : "Kiirtoimingu käivitamine ei õnnestu",
    "Quick action executed" : "Kiirtoiming on käivitatud",
    "No trash folder configured" : "Prügikasti kaust on määramata",
    "Could not delete message" : "Kirja kustutamine ei õnnestunud",
    "Could not archive message" : "Kirja arhiveerimine ei õnnestunud",
    "Thread was snoozed" : "Jutulõnga kuvamine on edasi lükatd",
    "Could not snooze thread" : "Ei õnnestunud edasi lükata jutulõnga kuvamist",
    "Thread was unsnoozed" : "Jutulõnga edasilükkamine on lõpetatud",
    "Could not unsnooze thread" : "Jutulõnga edasilükkamise lõpetamine ei õnnestunud",
    "This summary was AI generated" : "See koond on loodud tehisaru poolt",
    "Encrypted message" : "Krüptitud e-kiri",
    "This message is unread" : "See kiri on lugemata",
    "Unfavorite" : "Eemalda lemmikute seast",
    "Favorite" : "Lemmik",
    "Unread" : "Lugemata",
    "Read" : "Lugemine",
    "Unimportant" : "Vähetähtis",
    "Mark not spam" : "Eemalda rämpsposti märge",
    "Mark as spam" : "Märgi rämpspostiks",
    "Edit tags" : "Muuda silte",
    "Snooze" : "Lükka edasi",
    "Unsnooze" : "Lõpeta edasilükkamine",
    "Move thread" : "Tõsta jutulõng mujale",
    "Move Message" : "Teisalda kiri",
    "Archive thread" : "Arhiveeri jutulõng",
    "Archive message" : "Arhiveeri kiri",
    "Delete thread" : "Kustuta jutulõng",
    "Delete message" : "Kustuta kiri",
    "More actions" : "Täiendavad tegevused",
    "Back" : "Tagasi",
    "Set custom snooze" : "Vali edasilükkamise aeg",
    "Edit as new message" : "Muuda uue kirjana",
    "Reply with meeting" : "Vasta saates koosoleku teavet",
    "Create task" : "Loo ülesanne",
    "Download message" : "Laadi kiri alla",
    "Back to all actions" : "Tagasi kõikide toimingute juurde",
    "Manage quick actions" : "Halda kiirtoiminguid",
    "Load more" : "Laadi veel",
    "_Mark {number} read_::_Mark {number} read_" : ["Märgi {number} loetuks","Märgi {number} loetuks"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Märgi {number} mitteloetuks","Märgi {number} mitteloetuks"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Märgi {number} oluliseks","Märgi {number} oluliseks"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Märgi {number} mitteoluliseks","Märgi {number} mitteoluliseks"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Eemalda {number} lemmikute seast","Eemalda {number} lemmikute seast"],
    "_Favorite {number}_::_Favorite {number}_" : ["Lisa {number} kiri lemmikuks","Lisa {number} kirja lemmikuks"],
    "_Unselect {number}_::_Unselect {number}_" : ["Eemalda {number} kiri lemmikute seast","Eemalda {number} kirja lemmikute seast"],
    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Märgi {number} kiri rämpspostiks","Märgi {number} kirja rämpspostiks"],
    "_Mark {number} as not spam_::_Mark {number} as not spam_" : ["Eemalda {number}-lt kirjalt rämpsposti märge","Eemalda {number}-lt kirjalt rämpsposti märge"],
    "_Edit tags for {number}_::_Edit tags for {number}_" : ["Muuda {number} kirja silte","Muuda {number} kirja silte"],
    "_Move {number} thread_::_Move {number} threads_" : ["Teisalda {number} jutulõng","Teisalda {number} jutulõnga"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Edasta {number} kiri manusena","Edasta {number} kirja manusena"],
    "Mark as unread" : "Märgi mitteloetuks",
    "Mark as read" : "Märgi loetuks",
    "Mark as unimportant" : "Märgi mitteoluliseks",
    "Mark as important" : "Märgi oluliseks",
    "Report this bug" : "Teata sellest veast",
    "Event created" : "Sündmus on loodud",
    "Could not create event" : "Sündmuse loomine ei õnnestunud",
    "Create event" : "Lisa sündmus",
    "All day" : "Kogu päev",
    "Attendees" : "Osalejad",
    "You can only invite attendees if your account has an email address set" : "Sa saad kutsuda osalejaid vaid siis, kui sinu kasutajakontole on lisatud e-posti aadress",
    "Select calendar" : "Vali kalender",
    "Description" : "Kirjeldus",
    "Create" : "Loo",
    "This event was updated" : "See sündmus on uuendatud",
    "{attendeeName} accepted your invitation" : "„{attendeeName}“ on nõustunud sinu kutsega",
    "{attendeeName} tentatively accepted your invitation" : "„{attendeeName}“ on esialgselt nõustunud sinu kutsega",
    "{attendeeName} declined your invitation" : "„{attendeeName}“ ei võtnud sinu kutset vastu",
    "{attendeeName} reacted to your invitation" : "„{attendeeName}“ reageeris sinu kutsele",
    "Failed to save your participation status" : "Sinu osalemise oleku salvestamine ei õnnestunud",
    "You accepted this invitation" : "Sa nõustusid selle kutsega",
    "You tentatively accepted this invitation" : "Sa nõustusid selle kutsega esialgselt",
    "You declined this invitation" : "Sa ei võtnud seda kutset vastu",
    "You already reacted to this invitation" : "Sa juba oled sellele kutsele reageerinud",
    "You have been invited to an event" : "Sa said kutse sündmusele",
    "This event was cancelled" : "See sündmus on tühistatud",
    "Save to" : "Salvesta asukohta",
    "Select" : "Vali",
    "Comment" : "Kommentaar",
    "Accept" : "Nõustu",
    "Decline" : "Keeldu",
    "Tentatively accept" : "Nõustu esialgselt",
    "More options" : "Täiendavad valikud",
    "This message has an attached invitation but the invitation dates are in the past" : "Selle kirja manuses on kutse, kuid kutse kuupäevad  on minevikus.",
    "This message has an attached invitation but the invitation does not contain a participant that matches any configured mail account address" : "Selle kirja manuses on kutse, kuid kutses leidub osaleja, kes ei vasta ühelegi seadistatud e-posti aadressile.",
    "Could not remove internal address {sender}" : "Sisemise aadressi eemaldamine ei õnnestunud: {sender}",
    "Could not add internal address {address}" : "Sisemise aadressi lisamine ei õnnestunud: {address}",
    "individual" : "individuaalne",
    "domain" : "domeen",
    "Remove" : "Eemalda",
    "Add internal address" : "Lisa sisene aadress",
    "Add internal email or domain" : "Lisa sisene e-posti aadress või domeen",
    "Itinerary for {type} is not supported yet" : "Reisiplaani tüüp pole veel toetatud: {type}",
    "To archive a message please configure an archive folder in account settings" : "Kui tahad kirju arhiveerida, pead esmalt seadistustest valima arhiivikausta",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "Sul pole õigusi selle kirja arhiveerimiseks ega siit kaustast kustutamiseks või teisaldamiseks",
    "Your IMAP server does not support storing the seen/unseen state." : "Sinu e-posti server ei luba salvestada kirjade nähtud/mittenähtud olekuid.",
    "Could not mark message as seen/unseen" : "Ei õnnestunud märkida kirja nähtuks/mittenähtuks",
    "Last hour" : "Viimase tunni jooksul",
    "Today" : "Täna",
    "Yesterday" : "Eile",
    "Last week" : "Eelmisel nädalal",
    "Last month" : "Eelmisel kuul",
    "Could not open folder" : "Kausta avamine ei õnnestunud",
    "Loading messages …" : "Laadin kirju…",
    "Indexing your messages. This can take a bit longer for larger folders." : "Indekseerin sinu kirju. Kui kaustad on väga suured, siis võib kuluda natuke aega.",
    "Choose target folder" : "Vali sihtkaust",
    "No more submailboxes in here" : "Siin poel rohkem alampostkaste",
    "Favorites" : "Lemmikud",
    "Favorites info" : "Lemmikute teave",
    "Load more favorites" : "Laadi veel lemmikuid",
    "Load more follow ups" : "Laadi veel jätkukirju",
    "Important info" : "Oluline teave",
    "Load more important messages" : "Laadi veel olulisi kirju",
    "Other" : "Muu",
    "Load more other messages" : "Laadi veel muid kirju",
    "The sender of this message has asked to be notified when you read this message." : "Selle kirja saatja on palunud kinnitust, kui oled kirja lugenud.",
    "Notify the sender" : "Teavita saatjat",
    "You sent a read confirmation to the sender of this message." : "Sa saatsid selle kirja saatjale lugemisteatise.",
    "Message was snoozed" : "Kirja kuvamine on edasi lükatud",
    "Could not snooze message" : "Kirja kuvamist ei õnnestunud edasi lükata",
    "Message was unsnoozed" : "Kirja kuvamise edasilükkamine on lõpetatud",
    "Could not unsnooze message" : "Kirja kuvamise edasilükkamise lõpetamine ei õnnestunud",
    "Forward" : "Edasi",
    "Move message" : "Teisalda kiri",
    "Translate" : "Tõlgi",
    "Forward message as attachment" : "Edasta kiri manusena",
    "View source" : "Vaata kirja lähtekoodi",
    "Print message" : "Prindi kiri",
    "Create mail filter" : "E-posti filtri koostamine",
    "Download thread data for debugging" : "Laadi jutulõnga andmed veaotsinguks ja silumiseks alla",
    "Message body" : "Kirja sisu",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Hoiatus: Selle kirja S/MIME allkiri on verifitseerimata. Saatja võib esineda kellegi teisena!",
    "Unnamed" : "Nimeta",
    "Embedded message" : "Lõimitud kiri",
    "Attachment saved to Files" : "Manus on salvestatud failirakendusse",
    "Attachment could not be saved" : "Manus polnud võimalik salvestada",
    "calendar imported" : "kalender on imporditud",
    "Choose a folder to store the attachment in" : "Vali kaust, kuhu manus salvestada",
    "Import into calendar" : "Impordi kalendrisse",
    "Download attachment" : "Laadi manus alla",
    "Save to Files" : "Salvesta failirakendusse",
    "Attachments saved to Files" : "Manused on salvestatud failirakendusse",
    "Error while saving attachments" : "Viga manuse salvestamisel",
    "View fewer attachments" : "Näita vähem manuseid",
    "Choose a folder to store the attachments in" : "Vali kaust, kuhu soovid manuse salvestada",
    "Save all to Files" : "Salvesta kõik failirakendusse",
    "Download Zip" : "Laadi alla zip-fail",
    "_View {count} more attachment_::_View {count} more attachments_" : ["Vaata veel {count} manust","Vaata veel {count} manust"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "See kiri on krüptitud PGP abil. Dekrüptimiseks palun paigalda Mailvelope.",
    "The images have been blocked to protect your privacy." : "Kaitsmaks sinu privaatsust on piltide kuvamine blokeeritud.",
    "Show images" : "Näita pilte",
    "Show images temporarily" : "Näita pilte ajutiselt",
    "Always show images from {sender}" : "Alati näita pilte {sender} saatjalt",
    "Always show images from {domain}" : "Alati näita pilte {domain} domeenist",
    "Message frame" : "Kirja raam",
    "Quoted text" : "Tsiteeritud tekst",
    "Move" : "Liiguta",
    "Moving" : "Teisaldan",
    "Moving thread" : "Teisaldan jutulõnga mujale",
    "Moving message" : "Teisaldan kirja",
    "This account cannot connect" : "Selle kasutajakonto ühendamine ei õnnestu",
    "Connection failed. Please verify your information and try again" : "Ühendamine ei õnnestunud. Palun kontrolli, kas kõik sisestatud teave on õige ja proovi uuesti",
    "Used quota: {quota}% ({limit})" : "Kasutatud kvoot: {quota}% ({limit})",
    "Used quota: {quota}%" : "Kasutatud kvoot: {quota}%",
    "Unable to create mailbox. The name likely contains invalid characters. Please try another name." : "Postkasti pole võimalik luua. Ilmselt on nimes keelatud tähemärke. Palun proovi mõnda muud nime.",
    "Remove account" : "Eemalda konto",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "E-posti konto {email} ja tema puhverdatud andmed eemaldatakse siit Nextcloudi serverist, kuid mitte sinu e-postiteenuse pakkuja juurest.",
    "Remove {email}" : "Eemalda fail: „{email}“",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Selle konto kasutamiseks palun logi sisse salasõnaga. Praegune sessioon kasutab salasõnata tuvastamist, milleks võib olla SSO, WebAuthn, vms.",
    "Show only subscribed folders" : "Näita vaid tellitud kaustu",
    "Add folder" : "Lisa kaust",
    "Folder name" : "Kausta nimi",
    "Saving" : "Salvestan",
    "Move up" : "Liiguta ülespoole",
    "Move down" : "Liiguta allapoole",
    "Show all subscribed folders" : "Näita kõiki tellitud kaustu",
    "Show all folders" : "Näita kõiki kaustu",
    "Collapse folders" : "Ahenda kaustad",
    "_{total} message_::_{total} messages_" : ["{total} kiri","{total} kirja"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} lugemata kiri {total}-st kirjast","{unread} lugemata kirja {total}-st kirjast"],
    "Loading …" : "Andmed on laadimisel…",
    "All messages in mailbox will be deleted." : "Kõik kirjad sellest postkastist  kustutatakse.",
    "Clear mailbox {name}" : "Tühjenda postkast: {name}",
    "Clear folder" : "Tühjenda kaust",
    "The folder and all messages in it will be deleted." : "Kaust ja kõik temas leiduvad kirjad saavad järgnevaga kustutatud.",
    "Delete folder" : "Kustuta kaust",
    "Delete folder {name}" : "Kustuta kaust {name}",
    "An error occurred, unable to rename the mailbox." : "Tekkis viga ja postkasti nime muutmine pole võimalik.",
    "Please wait 10 minutes before repairing again" : "Enne uuesti parandamist palun oota 10 minutit",
    "Mark all as read" : "Märgi loetuks",
    "Add subfolder" : "Lisa alamkaust",
    "Rename" : "Muuda nime",
    "Move folder" : "Teisalda kaust",
    "Repair folder" : "Paranda kaust",
    "Clear cache" : "Tühjenda puhver",
    "Clear locally cached data, in case there are issues with synchronization." : "Kui sünkroniseerimisel tekib vigu, siis kustuta kohalikus seadmes puhverdatud andmed.",
    "Subscribed" : "Tellitud",
    "Sync in background" : "Sünkroniseeri taustal",
    "Delete all messages" : "Kustuta kõik sõnumid",
    "Outbox" : "Saadetud kirjad",
    "Translate this message to {language}" : "Tõlgi see e-kiri sihtkeelde: {language}",
    "New message" : "Uus kiri",
    "Edit message" : "Muuda kirja",
    "Draft" : "Kavand",
    "Reply" : "Vasta",
    "Message saved" : "Kiri on salvestatud",
    "Failed to save message" : "Kirja salvestamine ei õnnestu",
    "Failed to save draft" : "Mustandi salvestamine ei õnnestu",
    "attachment" : "manus",
    "attached" : "manus on lisatud",
    "No \"sent\" folder configured. Please pick one in the account settings." : "Saadetud kirjade kaust on seadistamata. Palun see seda kasutajakonto seadistustes.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Sa üritad saata kirja, kus saaja ja koopia välja on hiidpalju aadresse. Kirjasaajate privaatsuse ja mugavuse nimel palun kasuta pimekoopia välja.",
    "Your message has no subject. Do you want to send it anyway?" : "Sinu e-kirjal puudub teema. Kas sa kindlasti soovid seda saata?",
    "You mentioned an attachment. Did you forget to add it?" : "Sa mainisid, et tahad manuse lisada. Kas see ununes?",
    "Message discarded" : "Oled kirjast loobunud",
    "Could not discard message" : "Kirja koostamisest ja saatmisest ei õnnestunud loobuda",
    "Maximize composer" : "Näita koostamisvaadet suurena",
    "Show recipient details" : "Näita kirjasaaja üksikasju",
    "Hide recipient details" : "Peida kirjasaaja üksikasjad",
    "Minimize composer" : "Näita koostamisvaadet väiksena",
    "Error sending your message" : "Viga kirja saatmisel",
    "Retry" : "Proovi uuesti",
    "Warning sending your message" : "Hoiatus sinu kirja saatmisel",
    "Send anyway" : "Saada ikkagi",
    "Welcome to {productName} Mail" : "Tere tulemast  kasutama {productName}i Maili",
    "Start writing a message by clicking below or select an existing message to display its contents" : "Hakka koostama uut kirja klõpsides alljärgnevat või klõpsa mõnel kirjal tema lugemiseks",
    "Autoresponder off" : "Automaatvastaja on sees",
    "Autoresponder on" : "Automaatvastaja on väljas",
    "Autoresponder follows system settings" : "Automaatvastaja järgib süsteemi seadistusi",
    "The autoresponder follows your personal absence period settings." : "Automaatvastaja järgib sinu isikliku äraoleku perioodi seadistusi.",
    "Edit absence settings" : "Muuda äraoleku seadistusi",
    "First day" : "Esimene päev",
    "Last day (optional)" : "Viimane päev (valikuline)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} teema asendatakse vastatava kirja omaga",
    "Message" : "Kiri",
    "Oh Snap!" : "Appikene!",
    "Save autoresponder" : "Salvesta automaatvastaja",
    "Could not open outbox" : "Saadetud kirjade postkasti ei olnud võimalik avada",
    "Pending or not sent messages will show up here" : "Ootel või saatmata kirjad saavad olema nähtavad siin.",
    "Could not copy to \"Sent\" folder" : "Kirja on kopeerimine „Saadetud“ kausta ei õnnestunud",
    "Mail server error" : "E-posti serveri viga",
    "Message could not be sent" : "Kirja polnud võimalik saata",
    "Message deleted" : "Kiri on kustutatud",
    "Copy to \"Sent\" Folder" : "Kopeeri „Saadetud“ kirjade kausta",
    "Copy to Sent Folder" : "Kopeeri „Saadetud“ kirjade kausta",
    "Phishing email" : "Kurikaela õngitsuskiri",
    "This email might be a phishing attempt" : "See e-kiri võib olla üks õngitsuskatse",
    "Hide suspicious links" : "Peida kahtlased lingid",
    "Show suspicious links" : "Näita kahtlaseid linke",
    "link text" : "lingi tekst",
    "Copied email address to clipboard" : "E-posti aadress on kopeeritud lõikelauale.",
    "Could not copy email address to clipboard" : "E-posti aadressi kopeerimine lõikelauale ei õnnestunud.",
    "Contacts with this address" : "Selle aadressiga kontaktid",
    "Add to Contact" : "Lisa kontaktile",
    "New Contact" : "Uus kontakt",
    "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
    "Contact name …" : "Kontakti nimi…",
    "Add" : "Lisa",
    "Show less" : "Näita vähem",
    "Show more" : "Näita rohkem",
    "Clear" : "Tühjenda",
    "Search in folder" : "Otsi kaustast",
    "Open search modal" : "Ava modaalne otsinguvaade",
    "Close" : "Sulge",
    "Search parameters" : "Otsinguparameetrid",
    "Search subject" : "Otsi teemat",
    "Body" : "Sisu",
    "Search body" : "Otsi sisust",
    "Date" : "Kuupäev",
    "Pick a start date" : "Vali algkuupäev",
    "Pick an end date" : "Vali lõppkuupäev",
    "Select senders" : "Vali saatjad",
    "Select recipients" : "Vali saajad",
    "Select CC recipients" : "Vali koopia saajad",
    "Select BCC recipients" : "Vali pimekoopia saajad",
    "Tags" : "Sildid",
    "Select tags" : "Vali sildid",
    "Marked as" : "Märgutud kui",
    "Has attachments" : "Leidub manuseid",
    "Mentions me" : "Mainib mind",
    "Has attachment" : "Manusega",
    "To me" : "Mulle",
    "Enable mail body search" : "Otsi kirja sisust",
    "Sieve is a powerful language for writing filters for your mailbox. You can manage the sieve scripts in Mail if your email service supports it. Sieve is also required to use Autoresponder and Filters." : "Sieve on väga võimas keel, mille abil saad koostada filtreid oma postkastide jaoks. Kui sinu e-posti teenusepakkuja seda võimalust toetab, siis saad Sievet kasutada ka siin rakenduses. Sieve on vajalik rakenduse automaatvastaja ja kirjafiltrite jaoks.",
    "Enable sieve filter" : "Võta Sieve filter kasutusele",
    "Sieve host" : "Sieve server",
    "Sieve security" : "Sieve turvalisus",
    "Sieve Port" : "Sieve port",
    "Sieve credentials" : "Sieve kasutajanimi/salasõna",
    "IMAP credentials" : "IMAP-i kasutajanimi/salasõna",
    "Custom" : "Kohandatud",
    "Sieve User" : "Sieve'i kasutaja",
    "Sieve Password" : "Sieve'i salasõna",
    "Oh snap!" : "Appikene!",
    "Save sieve settings" : "Salvesta Sieve'i seadistused",
    "The syntax seems to be incorrect:" : "Süntaks tundub olema vigane:",
    "Save sieve script" : "Salvesta Sieve skript",
    "Signature …" : "Allkiri…",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Sinu e-kirjade allkiri on suurem, kui 2 MB ja see võib mõjutada kirjutamisliidese jõudlust.",
    "Save signature" : "Salvesta allkiri",
    "Place signature above quoted text" : "Aseta allkiri tsiteeritud teksti ette",
    "Message source" : "Kirja lähtekood",
    "An error occurred, unable to rename the tag." : "Tekkis viga ning sildi nime ei saanud muuta.",
    "Edit name or color" : "Muuda nime või värvi",
    "Saving new tag name …" : "Salvestan sildi uut nime…",
    "Delete tag" : "Kustuta silt",
    "Set tag" : "Lisa silt kirjale",
    "Unset tag" : "Eemalda silt kirjalt",
    "Tag name is a hidden system tag" : "Sildi nimi on peidetud süsteemne pilt",
    "Tag already exists" : "Silt on juba olemas",
    "Tag name cannot be empty" : "Sildi nimi ei saa jääda tühjaks",
    "An error occurred, unable to create the tag." : "Tekkis viga ning silti ei saanud luua.",
    "Add default tags" : "Lisa vaikimisi sildid",
    "Add tag" : "Lisa silt",
    "Saving tag …" : "Salvestan silti…",
    "Task created" : "Ülesanne on koostatud",
    "Could not create task" : "Ülesande koostamine ei õnnestunud",
    "No calendars with task list support" : "Pole ülesannete toega kalendrit",
    "Summarizing thread failed." : "Jutulõngast ei õnnestunud teha kokkuvõtet.",
    "Could not load your message thread" : "Sinu kirjade jutulõnga ei õnnestunud alla laadida",
    "The thread doesn't exist or has been deleted" : "Jutulõnga pole olemas või on kustutatud",
    "Email was not able to be opened" : "E-kirja polnud võimalik avada",
    "Print" : "Prindi",
    "Could not print message" : "Kirja printimine ei õnnestunud",
    "Loading thread" : "Laadin jutulõnga",
    "Not found" : "Ei leidu",
    "Encrypted & verified " : "Krüptitud ja verifitseeritud",
    "Signature verified" : "Allkiri on verifitseeritud",
    "Signature unverified " : "Allkiri on verifitseerimata",
    "This message was encrypted by the sender before it was sent." : "See kiri krüptiti enne saatmist saatja poolt.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Sellel kirjal on verifitseeritud  S/MIME allkiri. Kirja pole pärast saatmist  muudetud.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Sellel kirjal on verifitseerimata S/MIME allkiri. Kirja võib olla pärast saatmist muudetud või saatja sertifikaat pole usaldusväärne.",
    "Reply all" : "Vasta kõigile",
    "Unsubscribe request sent" : "Tellimusest loobumise päring on saadetud",
    "Could not unsubscribe from mailing list" : "Postiloendi tellimusest loobumine ei õnnestunud",
    "Please wait for the message to load" : "Palun oota, kuni e-kirja laadimine on lõppenud",
    "Disable reminder" : "Lülita meeldetuletus välja",
    "Unsubscribe" : "Lõpeta tellimus",
    "Reply to sender only" : "Vasta vaid saatjale",
    "Mark as unfavorite" : "Märgi mittelemmikuks",
    "Mark as favorite" : "Märgi lemmikuks",
    "Unsubscribe via link" : "Loobu tellimusest lingi kaudu",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "Tellimusest loobudes sa enam ei saa kirju postiloendist {sender}",
    "Send unsubscribe email" : "Saada loobumiskiri",
    "Unsubscribe via email" : "Saada tellimusest loobumine e-kirjana",
    "{name} Assistant" : "Abiline: {name}",
    "Thread summary" : "Jutulõnga kokkuvõte",
    "Go to latest message" : "Mine vanima kirja juurde",
    "Newest message" : "Viimane kiri",
    "This summary is AI generated and may contain mistakes." : "See kokkuvõte on tehisaru koostatud ja võib sisaldada vigu.",
    "Please select languages to translate to and from" : "Palun vali keeled, mille vahel tahad tõlkida",
    "The message could not be translated" : "E-kirja tõlkimine ei õnnestunud",
    "Translation copied to clipboard" : "Tõlge on kopeeritud lõikelauale",
    "Translation could not be copied" : "Tõlke kopeerimine ei õnnestunud",
    "Translate message" : "Tõlgi e-kiri",
    "Source language to translate from" : "Tõlke lähtekeel",
    "Translate from" : "Lähtekeel tõlkimisel",
    "Target language to translate into" : "Sihtkeel tõlkimisel",
    "Translate to" : "Tõlke sihtkeel",
    "Translating" : "Tõlkimisel",
    "Copy translated text" : "Kopeeri tõlgitud tekst",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Prügikasti sisu säilitamise saad keelata, kui jätad välja tühjaks või märkides selle 0-ks. Töödeldakse ainult pärast prügikasti säilitamise lubamist kustutatud e-kirju.",
    "Could not remove trusted sender {sender}" : "Usaldatud saatja eemaldamine ei õnnestunud: {sender}",
    "No senders are trusted at the moment." : "Sa hetkel ei usalda ühtegi kirjasaatjat.",
    "Untitled event" : "Ilma nimeta sündmus",
    "(organizer)" : "(korraldaja)",
    "Import into {calendar}" : "Impordi kalendrisse {calendar}",
    "Event imported into {calendar}" : "Sündmus on imporditud kalendrisse: {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Lend {flightNr}:  {depAirport} → {arrAirport}",
    "Airplane" : "Lennuk",
    "Reservation {id}" : "Broneering {id}",
    "{trainNr} from {depStation} to {arrStation}" : "Rong {trainNr}:  {depStation} → {arrStation}",
    "Train from {depStation} to {arrStation}" : "Rong: {depStation} → {arrStation}",
    "Train" : "Rong",
    "Mark message as" : "Märgi sõnumi olekuks",
    "Add flag" : "Lisa tunnus",
    "Move into folder" : "Tõsta kausta",
    "Stop" : "Lõpeta",
    "Delete action" : "Kustuta tegevus",
    "Answered" : "Vastatud",
    "Deleted" : "Kustutatud",
    "Flagged" : "Märgistatud",
    "Seen" : "Nähtud",
    "Enter flag" : "Sisesta tunnus",
    "Stop ends all processing" : "Peatamisel kogu töötlemine lõppeb",
    "Sender" : "Saatja",
    "Recipient" : "Saaja",
    "Create a new mail filter" : "Koosta uus e-posti filter",
    "Choose the headers you want to use to create your filter. In the next step, you will be able to refine the filter conditions and specify the actions to be taken on messages that match your criteria." : "Vali päisekirjed, mida tahad oma filtri loomisel kasutada. Järgmises sammus saad filtrite tingimusi täpsustada ja määratleda tegevused, mida nende täitmisel tehakse.",
    "Delete filter" : "Kustuta filter",
    "Delete mail filter {filterName}?" : "Kas kustutame e-posti filtri „{filterName}“?",
    "Are you sure to delete the mail filter?" : "Kas sa oled kindel, et soovid selle e-postifiltri kustutada?",
    "New filter" : "Uus filter",
    "Filter saved" : "Filter on salvestatud",
    "Could not save filter" : "Filtri salvestamine ei õnnestunud",
    "Filter deleted" : "Filter on kustutatud",
    "Could not delete filter" : "Filtri kustutamine on õnnestunud",
    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Halda e-kirjade kaost. Filtrid aitavad sul olulist esile tõsta ja müra eemaldada.",
    "Hang tight while the filters load" : "Palun oota, kuni filtrid saavad laaditud",
    "Filter is active" : "Filter on kasutusel",
    "Filter is not active" : "Filter pole kasutusel",
    "If all the conditions are met, the actions will be performed" : "Kui kõik tingimused vastavad siis, need tegevused käivitatakse",
    "If any of the conditions are met, the actions will be performed" : "Kui mõni tingimus vastab siis, need tegevused käivitatakse",
    "Help" : "Abiteave",
    "contains" : "sisaldab",
    "matches" : "kattub",
    "Enter subject" : "Sisesta teema",
    "Enter sender" : "Sisesta saatja",
    "Enter recipient" : "Sisesta saaja",
    "is exactly" : "on täpselt",
    "Conditions" : "Tingimused",
    "Add condition" : "Lisa tingimus",
    "Actions" : "Tegevused",
    "Add action" : "Lisa tegevus",
    "Priority" : "Olulisus",
    "Enable filter" : "Kasuta filtrit",
    "Tag" : "Silt",
    "delete" : "kustuta",
    "Edit quick action" : "Muuda kiirtoimingut",
    "Add quick action" : "Lisa kiirtoiming",
    "Quick action deleted" : "Kiirtoiming on kustutatud",
    "Failed to delete quick action" : "Kiirtoimingu kustutamine ei õnnestunud",
    "Failed to update quick action" : "Kiirtoimingu uuendamine ei õnnestunud",
    "Failed to update step in quick action" : "Kiirtoimingu sammu uuendamine ei õnnestunud",
    "Quick action updated" : "Kiirtoiming on uuendatud",
    "Failed to create quick action" : "Kiirtoimingu loomine ei õnnestunud",
    "Failed to add steps to quick action" : "Kiirtoimingule sammude lisamine ei õnnestunud",
    "Quick action created" : "Kiirtoiming on loodud",
    "Failed to delete action step" : "Toimingu sammu kustutamine ei õnnestunud",
    "No quick actions yet." : "Ühtegi kiirtoimingut veel pole",
    "Edit" : "Muuda",
    "Quick action name" : "Kiirtoimingu nimi",
    "Do the following actions" : "Tee järgnevad toimingud",
    "Add another action" : "Lisa veel üks toiming",
    "Successfully updated config for \"{domain}\"" : "„{domain}“ domeeni seadistuste uuendamine õnnestus",
    "Error saving config" : "Viga seadistuste salvestamisel",
    "Saved config for \"{domain}\"" : "„{domain}“ domeeni seadistused on salvestatud",
    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count} kasutajakonto ettevalmistamine õnnestus","{count} kasutajakonto ettevalmistamine õnnestus"],
    "Mail app" : "E-posti rakendus",
    "The mail app allows users to read mails on their IMAP accounts." : "Selle rakendusega saavad kasutajad lugeda oma IMAP-i kontode kirju.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Siin on serverikohased seadistused. Kasutajakohased seadistused leiduvad rakenduses (vaata alumist vasakut nurka).",
    "Add new config" : "Lisa uus konfiguratsioon",
    "Allow additional mail accounts" : "Lisa veel e-postikontosid",
    "Allow additional Mail accounts from User Settings" : "Luba kasutaja seadistustest täiendavate e-posti kontode kasutamine",
    "Enable text processing through LLMs" : "Kasuta teksti töötlemist suure keelemudeliga",
    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "E-postirakendus oskab töödelda kasutajaandmeid seadistatud keelemudeli abil ning selle teha abitoiminguid, nagu jutulõngade ülevaadete, nutikate vastuste ja ürituste päevakavade koostamine.",
    "Enable LLM processing" : "Lülita suure keelemudeliga töötlemine sisse",
    "Gmail integration" : "Lõiming Gmailiga",
    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail lubab kasutajatel lugeda kirju IMAP-i abil. Turvakaalutlustel toimib see vaid OAuth 2.0 liidestusega või kui Google'i konto kasutab kaheastmelist autentimist ja rakenduse salasõna.",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Sa pead Google Cloudi juhtpaneelis registreerima veebirakenduse (Web application) jaoks uue klienditunnuse (Client ID). Korrektse suunamisaadressina kasuta: {url}",
    "Microsoft integration" : "Lõiming Microsofti e-postiteenusega",
    "Microsoft requires you to access your emails via IMAP using OAuth 2.0 authentication. To do this, you need to register an app with Microsoft Entra ID, formerly known as Microsoft Azure Active Directory." : "Microsoft lubab kasutajatel lugeda kirju IMAP-i abil. Turvakaalutlustel toimib see vaid OAuth 2.0 liidestusega. Selleks palun registreeri oma rakendus teenuses Microsoft Entra ID, varasema nimega Microsoft Azure Active Directory.",
    "Redirect URI" : "Ümbersuunamise aadress (URI)",
    "For more details, please click here to open our documentation." : "Lisateavet leiad meie dokumentatsioonist ↗.",
    "User Interface Preference Defaults" : "Kasutusliidese eelistuste vaikimisi väärtused",
    "These settings are used to pre-configure the user interface preferences they can be overridden by the user in the mail settings" : "Need on kasutajaliidese eelseadistused, mida iga kasutaja saab oma seadistustest muuta",
    "Message View Mode" : "Kirjade vaate liik",
    "Show only the selected message" : "Näita vaid valitud kirja",
    "The original message will be attached as a \"message/rfc822\" attachment." : "Algne kiri lisatakse manusena „message/rfc822“ tüüpi failina.",
    "\"Mark as Spam\" Email Address" : "„Märgitud rämpspostiks“ e-posti aadressid",
    "\"Mark Not Junk\" Email Address" : "„Pole rämpspost“ e-posti aadressid",
    "Reset" : "Lähtesta",
    "Google integration configured" : "Google'i e-postiteenuste lõiming on seadistatud",
    "Could not configure Google integration" : "Google'i e-postiteenuste lõimingu seadistamine ei õnnestunud",
    "Google integration unlinked" : "Google'i e-postiteenuste lõiming on eemaldatud",
    "Could not unlink Google integration" : "Google'i e-postiteenuste lõimingu eemaldamine ei õnnestunud",
    "Client ID" : "Kliendi tunnus",
    "Client secret" : "Kliendi saladus",
    "Unlink" : "Eemalda lõiming",
    "Microsoft integration configured" : "Microsofti e-postiteenuste lõiming on seadistatud",
    "Could not configure Microsoft integration" : "Microsofti e-postiteenuste lõimingu seadistamine ei õnnestunud",
    "Microsoft integration unlinked" : "Microsofti e-postiteenuste lõiming on eemaldatud",
    "Could not unlink Microsoft integration" : "Microsofti e-postiteenuste lõimingu eemaldamine ei õnnestunud",
    "Tenant ID (optional)" : "Üüriliskasutaja tunnus (valikuline)",
    "Domain Match: {provisioningDomain}" : "Domeeni sobivus: {provisioningDomain}",
    "Email: {email}" : "E-post: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} serveris {host}:{port} ({ssl} krüptimisega)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} serveris {host}:{port} ({ssl} krüptimisega)",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} serveris {host}:{port} ({ssl} krüptimisega)",
    "Configuration for \"{provisioningDomain}\"" : "Seadistus „{provisioningDomain}“ domeeni jaoks",
    "Email address template" : "E-posti aadressi mall",
    "IMAP" : "IMAP",
    "User" : "Kasutaja",
    "Host" : "Host",
    "Port" : "Port",
    "SMTP" : "SMTP",
    "Master password" : "Üldsalasõna",
    "Use master password" : "Kasuta üldsalasõna",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Võta Sieve'i lõiming kasutusele",
    "LDAP aliases integration" : "LDAP-i aliaste lõiming",
    "Enable LDAP aliases integration" : "Võta kasutusele LDAP-i aliaste lõiming",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP-i aliaste lõiming võimaldab lugeda andmeid määratud LDAP-teenuse serverist ja selle alusel eelkoostada e-posti aliasi.",
    "LDAP attribute for aliases" : "LDAP-i omadused aliaste jaoks",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Mitmeväärtuseline e-posti aliaste eelkoostamise lahendus. Iga väärtuse kohta luuakse alias. Nexctcloudis leiduvate aliaste puhul, millel pole LDAP-i serveris vastet, kustutakse e-posti teenusest.",
    "Save Config" : "Salvesta seadistus",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% ja %EMAIL% asendatakse kasutajatunnuse (UID) ja e-posti aadressiga",
    "With the settings above, the app will create account settings in the following way:" : "Ülalmääratud seadistuste alusel loob rakendus kasutajakonto seadistused alljärgneval viisil:",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Lisatud PKCS #12 sertifikaadis peab olema vähemalt üks sertifikaat ning ainult üks privaatvõti.",
    "Failed to import the certificate. Please check the password." : "Sertifikaadi importimine ei õnnestunud. Palun kontrolli, kas salasõna on õige.",
    "Certificate imported successfully" : "Sertifikaadi importimine õnnestus",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Sertifikaadi importimine ei õnnestunud. Palun kontrolli, et privaatvõti vastab sertifikaadile ja ta ei ole salafraasiga krüptitud.",
    "Failed to import the certificate" : "Sertifikaadi importimine ei õnnestunud",
    "S/MIME certificates" : "S/MIME sertifikaadid",
    "Certificate name" : "Sertifikaadi nimi",
    "E-mail address" : "E-posti aadress",
    "Valid until" : "Kehtib kuni",
    "Delete certificate" : "Kustuta sertifikaat",
    "No certificate imported yet" : "Ühtegi sertifikaati pole imporditud",
    "Import certificate" : "Impordi sertifikaat",
    "Import S/MIME certificate" : "Impordi S/MIME sertifikaat",
    "PKCS #12 Certificate" : "PKCS #12 sertifikaat",
    "PEM Certificate" : "PEM sertifikaat",
    "Certificate" : "Sertifikaat",
    "Private key (optional)" : "Privaatvõti (kui vaja)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Privaatvõtit on vaja vaid siis, kui plaanid selle sertifikaadiga saata allkirjastatud ja krüptitud e-kirju.",
    "Submit" : "Saada",
    "No text blocks available" : "Ühtegi tekstiplokki pole saadaval",
    "Text block deleted" : "Tekstiplokk on kustutatud",
    "Failed to delete text block" : "Tekstiploki kustutamine ei õnnestunud",
    "Text block shared with {sharee}" : "Tekstiplokk on jagatud kasutajaga {sharee}",
    "Failed to share text block with {sharee}" : "Tekstiploki jagamine kasutajaga {sharee} ei õnnestunud",
    "Share deleted for {name}" : "{name} tekstiploki jagamine on eemaldatud",
    "Failed to delete share with {name}" : "{name} tekstiploki jagamise eemaldamine ei õnnestunud",
    "Guest" : "Külaline",
    "Group" : "Grupp",
    "Failed to save text block" : "Tekstiploki salvestamine ei õnnestunud",
    "Shared" : "Jagatud",
    "Edit {title}" : "Muuda: {title}",
    "Delete {title}" : "Kustuta: {title}",
    "Edit text block" : "Muuda tekstiplokki",
    "Shares" : "Jaoskaustad",
    "Search for users or groups" : "Otsi kasutajaid või gruppe",
    "Choose a text block to insert at the cursor" : "Vali kursori asukohast alates lisatav tekstiplokk",
    "Insert" : "Lisa",
    "Insert text block" : "Sisesta tekstiplokk",
    "Account connected" : "Konto ühendatud",
    "You can close this window" : "Võid selle akna sulgeda.",
    "Connect your mail account" : "Ühenda oma e-posti kontoga",
    "To add a mail account, please contact your administrator." : "Oma e-posti konto lisamiseks palun võta ühendust oma peakasutajaga.",
    "All" : "Kõik",
    "Drafts" : "Mustandid",
    "Priority inbox" : "Olulised kirjad",
    "All inboxes" : "Kõik postkastid",
    "Inbox" : "Postkast",
    "Junk" : "Rämpspost",
    "Sent" : "Saadetud",
    "Trash" : "Prügikast",
    "Connect OAUTH2 account" : "Ühenda OAUTH2 autentimist kasutava kontoga",
    "Error while sharing file" : "Viga faili jagamisel",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n uus kiri, \nmille saatis {from}","%n uut kirja, \nmille saatis {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Juba üks teine kiri on avatud. Kui jätkad, siis kõik salvestamata muudatused kaovad!",
    "Discard changes" : "Loobu muudatustest",
    "Discard unsaved changes" : "Loobu salvestamata muutustest",
    "Keep editing message" : "Jätka kirja kirjutamist",
    "Attachments were not copied. Please add them manually." : "Manused pole kopeeritud. Palun lisa nad käsitsi.",
    "Could not create snooze mailbox" : "Postkasti saabuvate kirjade saabumist ei õnnestunud edasi lükata",
    "Sending message…" : "Saadan kirja…",
    "Message sent" : "Kiri on saadetud",
    "Could not send message" : "Kirja saatmine ei õnnestu",
    "Message copied to \"Sent\" folder" : "Kiri on kopeeritud „Saadetud“ kausta",
    "Could not copy message to \"Sent\" folder" : "Kirja on kopeerimine „Saadetud“ kausta ei õnnestunud",
    "Could not load {tag}{name}{endtag}" : "Laadimine ei õnnestunud: {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Laadimisel tekkis viga: {tag}{name}{endtag}",
    "Could not load your message" : "Sinu kirja laadimine ei õnnestunud",
    "Could not load the desired message" : "Soovitud kirja laadimine ei õnnestunud",
    "Could not load the message" : "Kirja laadimine ei õnnestunud",
    "Error loading message" : "Viga kirja laadimisel",
    "Forwarding to %s" : "Edasta %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Kui sin paari sekundi jooksul edasi ei suunata, siis klõpsi siin.",
    "Redirect" : "Suunamine",
    "The link leads to %s" : "Link viitab siia: %s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Kui sa ei taha seda lehte avada, siis mine tagasi <a href=\"%s\">E-postirakenduse</a> lehele.",
    "Continue to %s" : "Jätka siia: %s",
    "Determine importance using machine learning" : "Määra olulisus masinõppe abil",
    "Mark all messages of this folder as read" : "Märgi kõik selle kausta kirjad loetuks",
    "Last 7 days" : "Viimase 7 päeva jooksul",
    "From me" : "Minult"
},
"nplurals=2; plural=(n != 1);");
